pub struct PGChecker {
pub config: PGOptions,
}Expand description
Check the validity of a backup stored as a file or directory.
We use the most recently modified timestamp of any file matching the user supplied pattern to find the most recent backup date.
Fields
config: PGOptionsThe configuration loaded from the initial YAML file.
Implementations